@@ -34,6 +34,7 @@ class RawTeamsConfig(BaseModel):
     delimiter: str = None
     rows: str
     name: str
+    affiliation: str
 
     class Config:
         frozen = True
@@ -48,6 +49,7 @@ class RawContestConfig(BaseModel):
     duration: str = None
     penalty_time: int = 0
     allow_submit: bool = True
+    with_statement: bool = False
 
     problems: Union[RawProblemsConfig, List[RawProblem]]
     teams: RawTeamsConfig
