@@ -3,9 +3,10 @@ from typing import List, Optional
 from datetime import datetime
 from dom.types.problem import ProblemPackage
 from dom.types.team import Team
+from dom.utils.pydantic import InspectMixin
 
 
-class ContestConfig(BaseModel):
+class ContestConfig(InspectMixin, BaseModel):
     name: str
     shortname: Optional[str] = None
     formal_name: Optional[str] = None
@@ -13,6 +14,7 @@ class ContestConfig(BaseModel):
     duration: Optional[str] = None
     penalty_time: Optional[int] = 0
     allow_submit: Optional[bool] = True
+    with_statement: Optional[bool] = False
 
     problems: List[ProblemPackage]
     teams: List[Team]
